@@ -1,13 +1,13 @@
-"""Enable CLI."""
+"""Enable CLI"""
 import asyncio
-import json
-from typing import List
 
 import click
 
+from aioazuredevops.builds import DevOpsBuild
 from aioazuredevops.client import DevOpsClient
 from aioazuredevops.core import DevOpsProject
-from aioazuredevops.builds import DevOpsBuild
+from aioazuredevops.wiql import DevOpsWiqlResult
+from aioazuredevops.work_item import DevOpsWorkItem
 
 
 @click.command()
@@ -16,15 +16,19 @@ from aioazuredevops.builds import DevOpsBuild
 @click.option("--pat", "-t", help="Personal Access Token")
 def cli(organization: str, project: str, pat: str = None):
     """CLI for this package."""
-    asyncio.run(handle(organization, project, pat))
+    asyncio.get_event_loop().run_until_complete(handle(organization, project, pat))
 
 
 async def handle(organization: str, project: str, pat: str = None) -> None:
+    """Handle CLI command"""
     client = DevOpsClient()
     if pat is not None:
-        if await client.authorize(pat, organization) is True:
-            print("Authenticated.")
+        await client.authorize(pat, organization)
+        print(client.authorized)
+        if client.authorized:
+            print("Authorized.")
         else:
+            print("Not authorized.")
             return
     print("Project:")
     doProject: DevOpsProject = await client.get_project(organization, project)
@@ -33,7 +37,7 @@ async def handle(organization: str, project: str, pat: str = None) -> None:
         print(doProject.name)
         print(doProject.description)
     print("Builds:")
-    builds: List[DevOpsBuild] = await client.get_builds(
+    builds: list[DevOpsBuild] = await client.get_builds(
         organization,
         project,
         "?queryOrder=queueTimeDescending&maxBuildsPerDefinition=1",
@@ -52,5 +56,28 @@ async def handle(organization: str, project: str, pat: str = None) -> None:
             print(build.project.id)
             print(build.project.name)
 
+    wiql_result: DevOpsWiqlResult = await client.get_work_items_ids_all(
+        organization,
+        project,
+    )
+    if wiql_result:
+        ids: list[int] = [item.id for item in wiql_result.work_items]
+        print("Work item ids:")
+        print(ids)
+
+        work_items: DevOpsWorkItem = await client.get_work_items(
+            organization,
+            project,
+            ids,
+        )
+        if work_items:
+            print("Work items:")
+            for item in work_items.value:
+                print("---------------------------------")
+                print(item.id)
+                print(item.fields.title)
+                print(item.fields.created_by.display_name)
+                print(item.fields.work_item_type)
+
 
 cli()  # pylint: disable=E1120
