@@ -1,14 +1,14 @@
-"""DevOps Core. https://docs.microsoft.com/en-gb/rest/api/azure/devops/core/?view=azure-devops-rest-5.1"""
+"""
+DevOps Core
+https://docs.microsoft.com/en-gb/rest/api/azure/devops/core/?view=azure-devops-rest-6.0
+"""
 from datetime import datetime
-from typing import List
 
 
 class DevOpsLinks:
     """Links."""
 
-    def __init__(
-        self, linkSelf: str = None, linkCollection: str = None, linkWeb: str = None
-    ):
+    def __init__(self, linkSelf: str = None, linkCollection: str = None, linkWeb: str = None):
         """Initialize"""
         self.self = linkSelf
         self.collection = linkCollection
